#
# spec file for package CorsixTH
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           CorsixTH
Version:        0.61
Release:        lp150.1.4
Summary:        Theme Hospital clone
License:        MIT
Group:          Amusements/Games/Strategy/Other
Url:            http://corsixth.com
Source:         https://github.com/CorsixTH/CorsixTH/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-devel
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpostproc)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libswscale)
%if 0%{?suse_version} > 1320
BuildRequires:  pkgconfig(luajit)
%else
BuildRequires:  lua51-luajit-devel
%endif
BuildRequires:  pkgconfig(sdl2)
Recommends:     timidity
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1210
BuildRequires:  lua51-devel
%else
BuildRequires:  lua-devel
%endif
Requires:       lua51-LPeg
Requires:       lua51-luafilesystem

%description
This project aims to reimplement the game engine of Theme Hospital, and be
able to load the original game data files. This means that you will need a
purchased copy of Theme Hospital, or a copy of the demo, in order to use
CorsixTH. After most of the original engine has been reimplemented in open
source code, the project will serve as a base from which extensions and
improvements to the original game can be made.

%prep
%setup -q

%build
# TODO: https://github.com/CorsixTH/CorsixTH/issues/1315
%cmake -DCMAKE_INSTALL_PREFIX=%{_libdir} -DWITH_MOVIES=OFF
make %{?_smp_mflags}

%install
pushd build
make DESTDIR=%{buildroot} install %{?_smp_mflags}
popd
mkdir -p %{buildroot}%{_bindir}
# create wrapper
cat <<EOF > %{buildroot}%{_bindir}/%{name}
#!/bin/sh
cd %{_libdir}/%{name}
./%{name}
cd -
EOF
chmod +x %{buildroot}%{_bindir}/%{name}
# install icons and desktop file
mkdir %{buildroot}%{_datadir}
mkdir %{buildroot}%{_datadir}/pixmaps
mv %{buildroot}%{_libdir}/CorsixTH/CorsixTH.ico %{buildroot}%{_datadir}/pixmaps
install -p -m 644 CorsixTH/Original_Logo.svg %{buildroot}%{_datadir}/pixmaps/CorsixTH.svg
%suse_update_desktop_file -c CorsixTH CorsixTH "A Theme Hospital Clone" CorsixTH CorsixTH Game Simulation

%files
%defattr(-,root,root)
%doc LICENSE.txt README.txt
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/applications/*
%{_datadir}/pixmaps/*

%changelog
* Sat Dec 30 2017 mailaender@opensuse.org
- Disable movies to workaround a segfault on startup
  https://github.com/CorsixTH/CorsixTH/issues/1315
* Thu Dec 28 2017 mailaender@opensuse.org
- Update to version 0.61
  - Mouse capture support. Now by default the mouse will be captured in its window. You can use CTRL-F10 to temporarily toggle the mouse capture state, or disable it in the config file.
  - Added multigesture movement and zoom for supported devices.
  - Fix for broken pathfinding involving the removal of side objects such as benches and radiators.
  - Allow objects to be built on top of litter and rat holes.
  - Fix for game error when handymen attempted to clean removed litter.
  - Can now click and hold to quickly change handyman priorities.
  - Significant map editor performance improvement when selecting multiple tiles.
  - If the config option to allow playing while paused is enabled, you can now make use of the bottom panel.
  - Fixed several bugs relating to the mood displays for staff and patients.
  - Rooms can now be built over top of trash.
  - Rat holes will now appear in dirty hospitals. Unfortunately the rats themselves are still hiding away.
  - Earthquakes now behave more like in Theme Hospital. A warning earthquake that does no damage will come first so that you can get ready for the big one. The damage calculations and visual effect have also been redone to be closer to the original game.
  - The game window can now be resized by dragging the edges.
  - We now avoid overlapping graph labels so all labels are readable.
  - Many many many bug fixes.
* Sat Jun 18 2016 mailaender@opensuse.org
- Update to version 0.60
  * Highlights from this release include:
  - User campaigns - It is now possible to create a series of levels that play together just like the original game.
  - In game map editor - A new map editor is available directly from the game menu.
  - Drug price impact - Patients will now react to the price you set for treatments. If treatments cost too much patients will opt to go home instead and this can affect your reputation.
  - Variable spawn rate - The spawn rate will now take into account your hospital's reputation (after a date set in the level file.)
  - Machine smoke is now visible when machines are close to worn out.
  - Right clicking the timer is now supported like in the original game for moving to affected patients - See issue #882 for details.
  - Numpad support - The number pad can now be used to move around the map when numlock is off, or to type numbers when numlock is on, without side effects.
  - The MP3 folder can now be unset from within the game. Previously after setting an mp3 folder it could only be removed by editing the config file by hand.
  - Uses the proper cursor for resizing rooms.
  - Bins can now be placed in the hallways.
  - Temperature impact has been tweaked. The initial grace period has been removed and the overall impact has been softened.
  - Custom maps can now be stored in a user directory separate from the levels shipped with the game.
  * Notable bug fixes:
  - Free build mode is now truly free - rooms used to cost money in this mode.
  - In game movies will now work correctly on more hardware.
  - Sound effects are no longer played when sound is disabled.
  - VIP rewards have been tweaked to closer match expectations when the impression is mediocre.
  - Crash when a patient is selected while they walk off the map is fixed.
  - A room built next to an unowned parcel no longer loses its wall when the parcel is bought.
  - Beta 1 regression that caused fired staff to continue to be paid has been patched.
  - Beta 1 regression that caused the last cured emergency patient not to count has been patched.
  - King complex patients only pay for their cure once.
  - Patients will notice when a room they are waiting for becomes available.
  - Properly load saves with more than one object on a tile.
  - Do not get stuck in an infinite loop when no disease is available to spawn.
* Tue May  3 2016 rpm@fthiessen.de
- Added fix-AVPixelFormat.patch to fix build with newer ffmpeg
  versions.
* Sat Nov 21 2015 rpm@fthiessen.de
- Update to version 0.50:
  * Really a lot of changes, bugfixes and enhancements, for a full
    list see:
    https://github.com/CorsixTH/CorsixTH/compare/v0.40...v0.50
  * spec file cleanup.
* Sat Dec 27 2014 erwin.vandevelde@gmail.com
- update to version 0.40
  - Gameplay
  * Added: Epidemics. You can either choose to pay a fine to the authorities or try to cover up the epidemic by vaccinating and curing the contagious patients. Patients going between buildings will NOT trigger the alarm to the authorities.
  * Added: The Grim Reaper. Previously patients have always gone to heaven when they die. No more! Sometimes they will instead fall down to the middle of the earth in a Lava Hole.
  * Added: People with visual diseases will no longer arrive at the beginning of the level if that has been specified in the level file. Instead they arrive once a certain amount of months have passed.
  * Added: If you refuse VIP visits a few times he can sometimes show up anyway.
  * Change: Machine usage and explosions are now based on absolute number of uses. A machine that goes down to 0 will explode. Previously they were percentage based.
  * Fix: The game would crash if you sacked a doctor in a room while a patient was using some equipment in that room.
  * Fix: Sometimes the emergency bonus was not correctly calculated.
  * Fix: Patients could die inside a room. They will now die outside the room unless they are just being cured.
  * Fix: If winning the level at end of year the annual report would hide the winning fax.
  * Fix: If there was no queue to a room a leaving staff member would not trigger a call for staff for the patient who had to abort their procedure in that room.
  * Fix: If a handyman had pending tasks when he died in an exploding room the game could crash.
  * Fix: A surgeon that is removed in mid-operation will now get properly replaced by a new one.
  * Fix: If the GP room was built too early in the tutorial the game would crash when building a GP room later on if debug mode was turned off.
  * Fix: Patients would try to enter an exploding room. As you can imagine, this was bad.
  * Fix: Psychiatrists would become shut-ins and just wander about their office forever.
  * Fix: Patients leaving the queue to get a drink could be left to sit on a bench forever.
  - User Interface
  * Added: Tooltips for the increase and decrease buttons in the research screen.
  * Added: A sound that indicates if a screenshot was taken successfully.
  * Added: Any dialog that pops up, such as the award screen, pauses the game.
  * Added: 'Continue Game' in the main menu.
  * Fix: Sometimes the game would not pause on year end.
  * Fix: Staff raise description was hard to read in some languages
  * Fix: The current language setting is translated and consistent with the options in the list.
  - Graphics
  * Fix: Instead of turning into a Bloaty Head, Baldness patients will die with gracious hair.
  * Fix: Patients will no longer fall through walls when dying.
  * Fix: Dying Hairyitis patients should not lose their head when on the floor.
  - Hotkeys
  * Added: 'Z' temporarily moves the game at maximum speed. Release to go back to the previous speed.
  * Added: 'X' makes walls transparent until released.
  * Added: Use the Numpad to change game speed.
  * Added: Arrow key hotkeys in the staff management screen.
  * Added: Press and hold on + and - when buying furniture to repeat the action.
  * Change: Quick Save is now Shift+Alt+S, Quick Load is Shift+Alt+L.
  - Languages
  * Change: "Plot" is used instead of "Parcel" to indicate where a handyman has been zoned to work in the Handyman staff dialog.
    Most languages have been updated since our last release, but if you find that your language has not, please help us to finish it!
    CorsixTH Development
  - Build
  * Added: New flag for CMAKE: 'WITH_LUAJIT'. This way you can choose to use either LuaJIT or Lua5.1.
  * Added: CMake toolchain for building with MinGW.
  * Added: New debug menu option 'Run debug Script' that executes <install_directory>/Lua/debug_script.lua
  * Improved OSX CMake scripts
* Sun Sep 28 2014 mailaender@opensuse.org
- update to version 0.30
  - Gameplay
  * Change: You can now build more than one desk in the ward. More nurses means a slightly faster throughput.
  * Change: Patients would previously queue outside toilets even though there were free loos since it was dependant on number of people in the room. Now, as soon as a loo becomes free another patient enters the room to use it, even if there is a long queue for the sink). If there is a queue for the sinks there is a chance the patient will leave without washing their hands - but will not be happy about doing this.
  * Added: The ability to control alien behaviour - sitting, knocking doors, only to be available through emergency or arrive like all other patients.
  * Added: Winning fax opens automatically and pauses the game.
  * Added: Option to automatically accept wage increase requests when they "time out".
  * Added: A new option allows for your average build content for each type of room to be remembered, so will be added for each new room built later.
  * Fix: Doctors should get stuck less often, and handymen should not crash the game as frequently.
  * Fix: It was not possible to replace a surgeon when a patient was in the room.
  * Fix: Patients would sometimes get stuck inside a room when they should have died.
  - User Interface
  * Added: A new customization menu in the Options dialog. Most options from the configuration file are now available for change in-game.
  * Added: A new directory menu in the Options dialog.
  * Added: The game does now check for a more recent version of itself when launching.
  * Added: A helpful message when the player puts more Researchers in the research department than there are desks.
  * Added: The game now does a small integrity check on the Theme Hospital files to make sure that the most common corruptions are not present.
  * Added: Confirm dialog to the quit/exit button on the main menu.
  * Fix: The tooltip for the tutorial button was incorrect since the dialog has been visually changed.
  * Fix: The announcer has had a few corrections made to his manuscripts. He is very happy about this!
  * Removed: The settings menu is no longer available from within the game.
  - Hotkeys
  * Some hotkeys have been changed and/or added:
  * Alt + A = Toggle Announcements
  * Alt + M = Toggle Music
  * Alt + S = Toggle Sound Effects
  * Shift and + to zoom in five steps and Shift and - to zoom out five steps at a time.
  - Campaign levels
  * Fix: An error in level 8 made it possible to win without meeting the reputation criterion.
  - Custom levels
  * Change: For random emergencies each illness now has its own average number of patients to spawn. Previously they were all the same.
  * Fix: Researching improvements was not really possible on some custom levels, i.e. if the map creator had made it so there were no machines at the start.
  - Demo files
  * Fix: When winning the demo level CorsixTH looked for another level to load, showing the wrong fax options and eventually crashing.
  - Languages
  * Added: Korean language.
  * Fix: It was not possible to dump strings for a language with unicode characters in the name.
* Sat Oct 12 2013 mailaender@opensuse.org
- update to version 0.21
  - Gameplay:
  * Fix: Staff would sometimes not go for a break.
  * Fix: A few crashes related to Handymen.
  * Fix: An error could occur if a fax message was removed just as it was animating into view.
  * Fix: Patients could sometimes be told to go home multiple times, resulting in a crash.
  * Fix: If a queueing patient was heading for a drinks machine just as the player moved that machine the game would crash.
  - User Interface
  * Added: Scrolling momentum when using the middle button.
  * Added: There is now a clock in the right corner of the menu bar that shows the real world time. It can be toggled between AM/PM and 24h in the configuration file.
  - Hotkeys
  * Added: Hotkeys for the Jukebox (J), Save game menu (Shift + S), Load game menu (Shift + L), to restart the level (Shift + R) and finally quit the current game and take you back to the opening screen (Shift + Q).
  * Change: Restart is now Shift + F10 instead of only F10.
  * Change: Toggle adviser is now Shift + A instead of only A.
  * Change: Key combinations will only trigger if that exact combination is pressed. E.g. Ctrl + R will not trigger R too.
  * Change: Alt + F4 is now the hotkey to quit CorsixTH.
  * Fix: Added a configuration option to have the possibility to use Shift + C as hotkey to open the Drug casebook instead of C. This is to workaround a bug that when you press on the volume down key on your keyboard the Drug casebook would open.
  - Map Editor
  * Added: Undo/Redo functionality.
  * Added: Street lamps and the dead looking tree.
* Fri Apr  5 2013 joop.boonen@opensuse.org
- Build without FFmpeg support
* Mon Mar 18 2013 dap.darkness@gmail.com
- update to version 0.20
  - Gameplay:
  * Added: "edge tile" objects now occupy just one edge of the tile.
  * Added: Possibility to play movies in-game (via ffmpeg libs).
  * Added: The atom analyzer can now be built in the research department.
  * Added: User actions are no allowed by default when the game is paused.
  * Added: Some background sounds, coughs, phones ringing etc.
  * Change: Placing a member of staff inside a room.
  - User Interface:
  * Added: You can see which drug company a certain drug was bought from.
  * Added: The adviser tells you why the research screen can't be opened.
  * Added: The Town Map functionality has been extended.
  * Added: Available options on open faxes now gets updated.
  * Added: Keyboard shortcuts F1 - F9 for the fullscreen windows.
  * Added: Possibility to choose font file in the options dialog.
  * Added: Player name is now customizable in the new game dialog.
  - Graphics:
  * Added: The graph dialog now displays graphs and statistics information.
  * Added: Choosing among three colour scales for warmth level.
  * Added: Print some info in the command prompt when taking a screenshot.
  * Added: Screenshot functionality for OpenGL version.
  * Change: Screenshots get saved to a dedicated screenshot folder now.
  - Translations:
  * Added: The beginning of Brazilian Portuguese and Hungarian.
  * Change: The "utf8" prefix has been obsolete and has been removed.
- Switched to use download_files service.
- Service source_validator was enabled.
* Mon Mar 18 2013 stefan@fam-elser.de
- update to version 0.11
  - Fix: Patients were not fully diagnosed according to settings in the policy screen.
  - Fix: The game now handles a player trying to cheat into an earthquake on levels 1-4.
  - Fix: It was not possible to sell equipment in rooms if you had a negative balance.
  - Fix: Handymen could not be placed inside rooms.
  - Fix: Handymen would get called to clean soot in blown up rooms.
  - Fix: Machines that need to be repaired will now cancel that request if they are blown up.
  - Fix: If a cured patient was leaving a room just as it crashed because of an earthquake the game would throw an error.
  - Fix: Alien DNA could under some circumstances not have the "concentrate research" button clicked without triggering a crash.
  - Fix: A crash occurring under some circumstances if the player picked up a staff member.
  - Enchancement: Since consultants are unable to learn new skills icons for not yet fully learned skills are now removed when a doctor is promoted.
  - Fix: Disabling background music no longer disables sound effects on Windows.
  - Fix: Checking if a sound exists crashed the game if there was no sound archive at all.
  - Fix: If the player paused the game from the top menu bar while an earthquake was active it would be impossible to scroll.
  - Fix: On a few levels some sliding doors would not animate correctly.
  - Fix: Vomiting standard males had the wrong animation.
* Fri Oct 12 2012 mailaender@opensuse.org
- update to version 0.10
  - Added: Earthquakes have recently been reported!
  - Added: Handyman priorities have been added. They can also be told to stay and respond to calls in one building (parcel) only.
  - Added: Staff's happiness will change due to more environmental factors.
  - Change: The files containing dumped strings are now created alongside the config file instead of in the installation directory.
  - Fix: Handymen will now meander inside a room until the machine which needs repair is free for use.
  - Fix: The URL in the config file pointing to better quality music was outdated. Note that this only affects new installations.
  - Fix: Two identical entries were shown in the drug casebook if a new disease was discovered when it was open.
  - Fix: Don't crash when a saved game with the town map open is loaded.
  - Fix: Too large rooms could make them unusable.
  - Some graphical glitches have been fixed.
  - Added: The Map Editor and Animation Viewer have new icons.
  - Change: In debug mode all gamelog output is now also displayed in the command prompt.
  - Fix: Don't initiate a window move if it happens to be below a top menu selection.
  - Fix: Don't show the main menu under any circumstances when closing the options menu in-game.
  - Fix: The "Save" and "Save As" buttons now do what they should do.
  - Fix: There were some strange log messages on opening the editor.
  - Added: The arrow keys can now be used to scroll the map.
  - Change: Removed a lot of tiles from the palette, since maps may not work as intended if they would be used.
* Sun Jun  3 2012 mailaender@opensuse.org
- update to version 0.01b
* Wed Apr 13 2011 prusnak@opensuse.org
- updated to beta 6
* Sun Dec 27 2009 prusnak@suse.cz
- created package
